@@ -194,11 +194,11 @@ def lsp_server_cmd(context: CommandContext) -> None:
     assert_can_start_lsp()
 
     from debputy.lsp.lsp_features import (
-        ensure_lsp_features_are_loaded,
+        ensure_cli_lsp_features_are_loaded,
     )
     from debputy.lsp.lsp_dispatch import DEBPUTY_LANGUAGE_SERVER
 
-    ensure_lsp_features_are_loaded()
+    ensure_cli_lsp_features_are_loaded()
     debputy_language_server = DEBPUTY_LANGUAGE_SERVER
     debputy_language_server.plugin_feature_set = feature_set
     debputy_language_server.dctrl_parser = context.dctrl_parser
@@ -333,9 +333,13 @@ def lint_cmd(context: CommandContext) -> None:
     except ImportError:
         _error("This feature requires lsprotocol (apt-get install python3-lsprotocol)")
 
+    from debputy.lsp.lsp_features import (
+        ensure_cli_lsp_features_are_loaded,
+    )
     from debputy.linting.lint_impl import perform_linting
 
     context.must_be_called_in_source_root()
+    ensure_cli_lsp_features_are_loaded()
     asyncio.run(perform_linting(context))
 
 
@@ -399,9 +403,13 @@ def reformat_cmd(context: CommandContext) -> None:
     except ImportError:
         _error("This feature requires lsprotocol (apt-get install python3-lsprotocol)")
 
+    from debputy.lsp.lsp_features import (
+        ensure_cli_lsp_features_are_loaded,
+    )
     from debputy.linting.lint_impl import perform_reformat
 
     context.must_be_called_in_source_root()
+    ensure_cli_lsp_features_are_loaded()
     perform_reformat(context, named_style=context.parsed_args.named_style)
 
 
@@ -475,11 +483,11 @@ def _load_test_lsp(
     assert_can_start_lsp()
 
     from debputy.lsp.lsp_features import (
-        ensure_lsp_features_are_loaded,
+        ensure_cli_lsp_features_are_loaded,
     )
     from debputy.lsp.lsp_dispatch import DEBPUTY_LANGUAGE_SERVER
 
-    ensure_lsp_features_are_loaded()
+    ensure_cli_lsp_features_are_loaded()
     debputy_language_server = DEBPUTY_LANGUAGE_SERVER
     debputy_language_server.plugin_feature_set = context.load_plugins()
     debputy_language_server.dctrl_parser = context.dctrl_parser
