@@ -760,6 +760,8 @@ def relocate_dwarves_into_dbgsym_packages(
     dctrl: BinaryPackage,
     package_fs_root: FSPath,
     dbgsym_fs_root: VirtualPath,
+    *,
+    run_dwz: bool = False,
 ) -> List[str]:
     # FIXME: hardlinks
     with _all_static_libs(package_fs_root) as all_static_files:
@@ -793,7 +795,8 @@ def relocate_dwarves_into_dbgsym_packages(
             e for e in all_elf_files.values() if not e.is_stripped
         )
 
-        _run_dwz(dctrl, dbgsym_fs_root, unstripped_elf_info)
+        if run_dwz:
+            _run_dwz(dctrl, dbgsym_fs_root, unstripped_elf_info)
 
         for elf_info in unstripped_elf_info:
             elf_info.dbgsym = _make_debug_file(
