@@ -275,7 +275,8 @@ def migrate_from_dh(
         )
 
     # We start on compat 12 for arch:any due to the new dh_makeshlibs and dh_installinit default
-    min_compat = 12
+    # For arch:any, the min is compat 14 due to `dh_dwz` being removed.
+    min_compat = 14 if any(not p.is_arch_all for p in manifest.all_packages) else 12
     min_compat = max(
         (m.assumed_compat for m in migrations if m.assumed_compat is not None),
         default=min_compat,
