@@ -58,7 +58,7 @@ from .plugin.api.impl_types import (
 )
 from debputy.plugin.api.parser_tables import OPARSER_MANIFEST_ROOT
 from .plugin.api.spec import DebputyIntegrationMode
-from .plugin.debputy.to_be_api_types import BuildRule
+from debputy.plugins.debputy.build_system_rules import BuildRule
 from .yaml import YAMLError, MANIFEST_YAML
 
 try:
@@ -240,7 +240,7 @@ class HighLevelManifestParser(ParserContextData):
         if isinstance(self, YAMLManifestParser) and self._mutable_yaml_manifest is None:
             self._mutable_yaml_manifest = MutableYAMLManifest.empty_manifest()
         all_packager_provided_files = detect_all_packager_provided_files(
-            self._plugin_provided_feature_set.packager_provided_files,
+            self._plugin_provided_feature_set,
             self._debian_dir,
             self.binary_packages,
         )
