@@ -50,6 +50,7 @@ from debputy.lsp.lsp_features import (
     lsp_text_doc_inlay_hints,
     LanguageDispatchRule,
     SecondaryLanguage,
+    lsp_cli_reformat_document,
 )
 from debputy.lsp.lsp_generic_deb822 import (
     deb822_completer,
@@ -1051,6 +1052,7 @@ def _debian_control_on_save_formatting(
     return _reformat_debian_control(lint_state)
 
 
+@lsp_cli_reformat_document(_DISPATCH_RULE)
 def _reformat_debian_control(
     lint_state: LintState,
 ) -> Optional[Sequence[TextEdit]]:
