@@ -57,6 +57,7 @@ _WAS_DEFAULTS = {
     "deb822_trailing_separator": False,
     "deb822_normalize_stanza_order": False,
     "deb822_normalize_field_content": True,
+    "deb822_auto_canonical_size_field_names": False,
 }
 
 
@@ -279,6 +280,13 @@ FORMATTING_OPTIONS = [
     example, `Description` (`debian/control`) or `License` (`debian/copyright`) will not
     be affected by this option.
 
+    This setting may affect style-related diagnostics. Notably, many tools with linting or
+    diagnostics capabilities (`debputy` included) will generally flag lines of 80 or more
+    characters as suboptimal. The diagnostics are because some fields are displayed to end
+    users in settings where 80 character-wide displays are or were the norm with no or
+    only awkward horizontal scrolling options available. Using a value higher than the
+    default may cause undesired diagnostics.
+
     Note: When `formatting.deb822.always-wrap` is `true`, then this option will be overruled.
     Additionally, this only triggers when a field is being reformatted. Generally that requires
     another option such as `formatting.deb822.normalize-field-content` for that to happen.
@@ -406,6 +414,42 @@ FORMATTING_OPTIONS = [
     """
         ),
     ),
+    PreferenceOption(
+        key=["deb822", "auto-canonical-size-field-names"],
+        expected_type=bool,
+        default_value=False,
+        description=textwrap.dedent(
+            """\
+    Whether to canonical field names of known `deb822` fields.
+
+    This causes formatting to align known fields in `deb822` files with their
+    canonical spelling. As an examples:
+
+    ```
+    source: foo
+    RULES-REQUIRES-ROOT: no
+    ```
+
+    Would be reformatted as:
+
+    ```
+    Source: foo
+    Rules-Requires-Root: no
+    ```
+
+    The formatting only applies when the canonical spelling of the field is known
+    to `debputy`. Unknown fields retain their original casing/formatting.
+
+    This setting may affect style-related diagnostics. Notably, many tools with linting or
+    diagnostics capabilities (`debputy` included) will generally flag non-canonical spellings
+    of field names as suboptimal. Note that while `debputy` will only flag and correct
+    non-canonical casing of fields, some tooling may be more opinionated and flag even
+    fields they do not know using an algorithm to guess the canonical casing. Therefore,
+    even with this enabled, you can still canonical spelling related diagnostics from
+    other tooling.
+    """
+        ),
+    ),
 ]
 
 
@@ -418,6 +462,7 @@ class EffectiveFormattingPreference:
     deb822_normalize_field_order: bool = False
     deb822_normalize_stanza_order: bool = False
     deb822_max_line_length: int = 79
+    deb822_auto_canonical_size_field_names: bool = False
 
     @classmethod
     def from_file(
