@@ -555,15 +555,19 @@ class ParserGenerator:
             Container[DebputyIntegrationMode]
         ] = None,
         unknown_keys_diagnostic_severity: Optional[LintSeverity] = "error",
-    ) -> None:
+        allow_unknown_keys: bool = False,
+    ) -> DispatchingObjectParser:
         assert path not in self._in_package_context_parser
         assert path not in self._object_parsers
-        self._object_parsers[path] = DispatchingObjectParser(
+        object_parser = DispatchingObjectParser(
             path,
             parser_documentation=parser_documentation,
             expected_debputy_integration_mode=expected_debputy_integration_mode,
             unknown_keys_diagnostic_severity=unknown_keys_diagnostic_severity,
+            allow_unknown_keys=allow_unknown_keys,
         )
+        self._object_parsers[path] = object_parser
+        return object_parser
 
     def add_in_package_context_parser(
         self,
@@ -985,16 +989,20 @@ class ParserGenerator:
             provided_type,
             parsing_typed_dict_attribute,
         )
-        t_unmapped, t_orig, t_args = unpack_type(
+        t_unmapped, t_unmapped_orig, t_unmapped_args = unpack_type(
             unmapped_type,
             parsing_typed_dict_attribute,
         )
+        _, t_provided_orig, t_provided_args = unpack_type(
+            provided_type,
+            parsing_typed_dict_attribute,
+        )
 
         if (
-            t_orig == Union
-            and t_args
-            and len(t_args) == 2
-            and any(v is _NONE_TYPE for v in t_args)
+            t_unmapped_orig == Union
+            and t_unmapped_args
+            and len(t_unmapped_args) == 2
+            and any(v is _NONE_TYPE for v in t_unmapped_args)
         ):
             _, _, args = unpack_type(provided_type, parsing_typed_dict_attribute)
             actual_type = [a for a in args if a is not _NONE_TYPE][0]
@@ -1036,16 +1044,13 @@ class ParserGenerator:
                 base_type=unmapped_type,
                 mapper=type_normalizer,
             )
-        if t_orig == list:
-            if not t_args:
+        if t_unmapped_orig == list:
+            if not t_unmapped_args:
                 raise ValueError(
                     f'The attribute "{attribute}" is List but does not have Generics (Must use List[X])'
                 )
-            _, t_provided_orig, t_provided_args = unpack_type(
-                provided_type,
-                parsing_typed_dict_attribute,
-            )
-            genetic_type = t_args[0]
+
+            genetic_type = t_unmapped_args[0]
             key_mapper = self._as_type_validator(
                 attribute,
                 genetic_type,
@@ -1080,24 +1085,24 @@ class ParserGenerator:
                     v, ap, parser_context=cv
                 ),
             )
-        if t_orig == dict:
-            if not t_args or len(t_args) != 2:
+        if t_unmapped_orig == dict:
+            if not t_unmapped_args or len(t_unmapped_args) != 2:
                 raise ValueError(
                     f'The attribute "{attribute}" is Dict but does not have Generics (Must use Dict[str, Y])'
                 )
-            if t_args[0] != str:
+            if t_unmapped_args[0] != str:
                 raise ValueError(
                     f'The attribute "{attribute}" is Dict and has a non-str type as key.'
                     " Currently, only `str` is supported (Dict[str, Y])"
                 )
             key_mapper = self._as_type_validator(
                 attribute,
-                t_args[0],
+                t_unmapped_args[0],
                 parsing_typed_dict_attribute,
             )
             value_mapper = self._as_type_validator(
                 attribute,
-                t_args[1],
+                t_unmapped_args[1],
                 parsing_typed_dict_attribute,
             )
 
@@ -1134,11 +1139,13 @@ class ParserGenerator:
                 base_type=dict,
                 mapper=type_normalizer,
             ).combine_mapper(key_mapper.mapper)
-        if t_orig == Union:
-            if _is_two_arg_x_list_x(t_args):
+        if t_unmapped_orig == Union:
+            if _is_two_arg_x_list_x(t_provided_args):
                 # Force the order to be "X, List[X]" as it simplifies the code
                 x_list_x = (
-                    t_args if get_origin(t_args[1]) == list else (t_args[1], t_args[0])
+                    t_provided_args
+                    if get_origin(t_provided_args[1]) == list
+                    else (t_provided_args[1], t_provided_args[0])
                 )
 
                 # X, List[X] could match if X was List[Y].  However, our code below assumes
@@ -1172,7 +1179,7 @@ class ParserGenerator:
             else:
                 subtype_checker = [
                     self._as_type_validator(attribute, a, parsing_typed_dict_attribute)
-                    for a in t_args
+                    for a in t_unmapped_args
                 ]
                 type_description = "one-of: " + ", ".join(
                     f"{sc.describe_type()}" for sc in subtype_checker
@@ -1206,14 +1213,14 @@ class ParserGenerator:
                     _validator,
                     mapper=type_normalizer,
                 )
-        if t_orig == Literal:
+        if t_unmapped_orig == Literal:
             # We want "x" for string values; repr provides 'x'
             pretty = ", ".join(
-                f'"{v}"' if isinstance(v, str) else str(v) for v in t_args
+                f"`{v}`" if isinstance(v, str) else str(v) for v in t_unmapped_args
             )
 
             def _validator(v: Any, path: AttributePath) -> None:
-                if v not in t_args:
+                if v not in t_unmapped_args:
                     value_hint = ""
                     if isinstance(v, str):
                         value_hint = f"({v}) "
